b-i
======

BI tools  for data developer use Python Language. 更快捷的BI数据开发工具

[![Build Status](https://img.shields.io/travis/otale/tale.svg?style=flat-square)](https://github.com/cppla/dblib)
[![](https://img.shields.io/badge/python-3.6%2B%20-blue.svg)](https://github.com/cppla/dblib)
[![License](https://img.shields.io/badge/license-MIT-4EB1BA.svg?style=flat-square)](https://github.com/cppla/dblib)

简介
========

todo： 这里是描述

示例
========

todo： 这里是使用教程
